@@ -58,21 +58,21 @@ AbstractProxyResponseCommand::AbstractProxyResponseCommand
  DownloadEngine* e,
  const SocketHandle& s)
   :AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
-   httpConnection(httpConnection) {}
+   httpConnection_(httpConnection) {}
 
 AbstractProxyResponseCommand::~AbstractProxyResponseCommand() {}
 
 bool AbstractProxyResponseCommand::executeInternal() {
-  SharedHandle<HttpResponse> httpResponse = httpConnection->receiveResponse();
-  if(httpResponse.isNull()) {
+  SharedHandle<HttpResponse> httpResponse = httpConnection_->receiveResponse();
+  if(!httpResponse) {
     // the server has not responded our request yet.
-    e->commands.push_back(this);
+    getDownloadEngine()->addCommand(this);
     return false;
   }
-  if(httpResponse->getResponseStatus() != HttpHeader::S200) {
+  if(httpResponse->getStatusCode() != 200) {
     throw DL_RETRY_EX(EX_PROXY_CONNECTION_FAILED);
   }
-  e->commands.push_back(getNextCommand());
+  getDownloadEngine()->addCommand(getNextCommand());
   return true;
 }
 
