@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BYTE_ARRAY_DISK_WRITER_H_
-#define _D_BYTE_ARRAY_DISK_WRITER_H_
+#ifndef D_BYTE_ARRAY_DISK_WRITER_H
+#define D_BYTE_ARRAY_DISK_WRITER_H
 
 #include "DiskWriter.h"
 #include <sstream>
@@ -42,7 +42,7 @@ namespace aria2 {
 
 class ByteArrayDiskWriter : public DiskWriter {
 private:
-  std::stringstream buf;
+  std::stringstream buf_;
 
   void clear();
 public:
@@ -66,19 +66,13 @@ public:
 
   virtual void disableDirectIO() {}
 
-  void setString(const std::string& s)
-  {
-    buf.str(s);
-  }
+  void setString(const std::string& s);
 
-  std::string getString() const
-  {
-    return buf.str();
-  }
+  std::string getString() const;
 };
 
 typedef SharedHandle<ByteArrayDiskWriter> ByteArrayDiskWriterHandle;
 
 } // namespace aria2
 
-#endif // _D_BYTE_ARRAY_DISK_WRITER_H_
+#endif // D_BYTE_ARRAY_DISK_WRITER_H
