@@ -34,7 +34,6 @@
 /* copyright --> */
 #include "DHTAutoSaveCommand.h"
 
-#include <cerrno>
 #include <cstring>
 #include <fstream>
 
@@ -44,27 +43,25 @@
 #include "DHTRoutingTableSerializer.h"
 #include "RecoverableException.h"
 #include "DownloadEngine.h"
-#include "util.h"
 #include "DHTBucket.h"
 #include "RequestGroupMan.h"
 #include "prefs.h"
 #include "Option.h"
 #include "message.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "a2functional.h"
 #include "FileEntry.h"
 #include "DlAbortEx.h"
-#include "StringFormat.h"
-#include "ServerStatMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
+#include "fmt.h"
 
 namespace aria2 {
 
 DHTAutoSaveCommand::DHTAutoSaveCommand
-(cuid_t cuid, DownloadEngine* e, int family, time_t interval):
-  TimeBasedCommand(cuid, e, interval),
-  family_(family) {}
+(cuid_t cuid, DownloadEngine* e, int family, time_t interval)
+ : TimeBasedCommand(cuid, e, interval),
+   family_(family)
+{}
 
 DHTAutoSaveCommand::~DHTAutoSaveCommand() {}
 
@@ -87,7 +84,7 @@ void DHTAutoSaveCommand::save()
   std::string dhtFile =
     getDownloadEngine()->getOption()->
     get(family_ == AF_INET? PREF_DHT_FILE_PATH : PREF_DHT_FILE_PATH6);
-  getLogger()->info("Saving DHT routing table to %s.", dhtFile.c_str());
+  A2_LOG_INFO(fmt("Saving DHT routing table to %s.", dhtFile.c_str()));
 
   File tempFile(dhtFile+"__temp");
   // Removing tempFile is unnecessary because the file is truncated on
@@ -117,18 +114,19 @@ void DHTAutoSaveCommand::save()
                       std::ios::out|std::ios::binary);
       if(!o) {
         throw DL_ABORT_EX
-          (StringFormat("Failed to save DHT routing table to %s. cause:%s",
-                        dhtFile.c_str(), strerror(errno)).str());
+          (fmt("Failed to save DHT routing table to %s.",
+               dhtFile.c_str()));
       }
       serializer.serialize(o);
     }
     if(!tempFile.renameTo(dhtFile)) {
-      getLogger()->error("Cannot move file from %s to %s.",
-                         tempFile.getPath().c_str(), dhtFile.c_str());
+      A2_LOG_ERROR(fmt("Cannot move file from %s to %s.",
+                       tempFile.getPath().c_str(), dhtFile.c_str()));
     }
   } catch(RecoverableException& e) {
-    getLogger()->error("Exception caught while saving DHT routing table to %s",
-                       e, dhtFile.c_str());
+    A2_LOG_ERROR_EX(fmt("Exception caught while saving DHT routing table to %s",
+                        dhtFile.c_str()),
+                    e);
   }
 }
 
