@@ -40,7 +40,6 @@
 #include "LogFactory.h"
 #include "Logger.h"
 #include "util.h"
-#include "File.h"
 #include "DHTNode.h"
 #include "DHTConnectionImpl.h"
 #include "DHTRoutingTable.h"
@@ -70,25 +69,22 @@
 #include "RecoverableException.h"
 #include "a2functional.h"
 #include "DownloadEngine.h"
-#include "wallclock.h"
-#include "RequestGroupMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
-#include "ServerStatMan.h"
-#include "FileEntry.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-// TODO DownloadEngine should hold this flag.
-bool DHTSetup::initialized_ = false;
-
-DHTSetup::DHTSetup():logger_(LogFactory::getInstance()) {}
+DHTSetup::DHTSetup() {}
 
 DHTSetup::~DHTSetup() {}
 
-void DHTSetup::setup(std::vector<Command*>& commands, DownloadEngine* e)
+void DHTSetup::setup
+(std::vector<Command*>& commands, DownloadEngine* e, int family)
 {
-  if(initialized_) {
+  if(family != AF_INET && family != AF_INET6) {
+    return;
+  }
+  if((family == AF_INET && DHTRegistry::isInitialized()) ||
+     (family == AF_INET6 && DHTRegistry::isInitialized6())) {
     return;
   }
   try {
@@ -98,8 +94,10 @@ void DHTSetup::setup(std::vector<Command*>& commands, DownloadEngine* e)
 
     SharedHandle<DHTNode> localNode;
 
-    DHTRoutingTableDeserializer deserializer;
-    std::string dhtFile = e->getOption()->get(PREF_DHT_FILE_PATH);
+    DHTRoutingTableDeserializer deserializer(family);
+    const std::string& dhtFile =
+      e->getOption()->get(family == AF_INET?PREF_DHT_FILE_PATH:
+                          PREF_DHT_FILE_PATH6);
     try {
       std::ifstream in(dhtFile.c_str(), std::ios::binary);
       if(!in) {
@@ -108,30 +106,34 @@ void DHTSetup::setup(std::vector<Command*>& commands, DownloadEngine* e)
       deserializer.deserialize(in);
       localNode = deserializer.getLocalNode();
     } catch(RecoverableException& e) {
-      logger_->error("Exception caught while loading DHT routing table from %s",
-                     e, dhtFile.c_str());
+      A2_LOG_ERROR_EX
+        (fmt("Exception caught while loading DHT routing table from %s",
+             dhtFile.c_str()),
+         e);
     }
-    if(localNode.isNull()) {
+    if(!localNode) {
       localNode.reset(new DHTNode());
     }
 
-    SharedHandle<DHTConnectionImpl> connection(new DHTConnectionImpl());
+    SharedHandle<DHTConnectionImpl> connection(new DHTConnectionImpl(family));
     {
       IntSequence seq =
         util::parseIntRange(e->getOption()->get(PREF_DHT_LISTEN_PORT));
       uint16_t port;
-      if(!connection->bind(port, seq)) {
+      const std::string& addr =
+        e->getOption()->get(family == AF_INET?PREF_DHT_LISTEN_ADDR:
+                            PREF_DHT_LISTEN_ADDR6);
+      if(!connection->bind(port, addr, seq)) {
         throw DL_ABORT_EX("Error occurred while binding port for DHT");
       }
       localNode->setPort(port);
     }
-    if(logger_->debug()) {
-      logger_->debug("Initialized local node ID=%s",
-                     util::toHex(localNode->getID(), DHT_ID_LENGTH).c_str());
-    }
+    A2_LOG_DEBUG(fmt("Initialized local node ID=%s",
+                     util::toHex(localNode->getID(), DHT_ID_LENGTH).c_str()));
     SharedHandle<DHTRoutingTable> routingTable(new DHTRoutingTable(localNode));
 
-    SharedHandle<DHTMessageFactoryImpl> factory(new DHTMessageFactoryImpl());
+    SharedHandle<DHTMessageFactoryImpl> factory
+      (new DHTMessageFactoryImpl(family));
 
     SharedHandle<DHTMessageTracker> tracker(new DHTMessageTracker());
 
@@ -159,10 +161,10 @@ void DHTSetup::setup(std::vector<Command*>& commands, DownloadEngine* e)
     receiver->setRoutingTable(routingTable);
 
     taskFactory->setLocalNode(localNode);
-    taskFactory->setRoutingTable(routingTable);
-    taskFactory->setMessageDispatcher(dispatcher);
-    taskFactory->setMessageFactory(factory);
-    taskFactory->setTaskQueue(taskQueue);
+    taskFactory->setRoutingTable(routingTable.get());
+    taskFactory->setMessageDispatcher(dispatcher.get());
+    taskFactory->setMessageFactory(factory.get());
+    taskFactory->setTaskQueue(taskQueue.get());
     taskFactory->setTimeout(messageTimeout);
 
     routingTable->setTaskQueue(taskQueue);
@@ -171,24 +173,35 @@ void DHTSetup::setup(std::vector<Command*>& commands, DownloadEngine* e)
     peerAnnounceStorage->setTaskQueue(taskQueue);
     peerAnnounceStorage->setTaskFactory(taskFactory);
 
-    factory->setRoutingTable(routingTable);
-    factory->setConnection(connection);
-    factory->setMessageDispatcher(dispatcher);
-    factory->setPeerAnnounceStorage(peerAnnounceStorage);
-    factory->setTokenTracker(tokenTracker);
+    factory->setRoutingTable(routingTable.get());
+    factory->setConnection(connection.get());
+    factory->setMessageDispatcher(dispatcher.get());
+    factory->setPeerAnnounceStorage(peerAnnounceStorage.get());
+    factory->setTokenTracker(tokenTracker.get());
     factory->setLocalNode(localNode);
 
     // assign them into DHTRegistry
-    DHTRegistry::getMutableData().localNode = localNode;
-    DHTRegistry::getMutableData().routingTable = routingTable;
-    DHTRegistry::getMutableData().taskQueue = taskQueue;
-    DHTRegistry::getMutableData().taskFactory = taskFactory;
-    DHTRegistry::getMutableData().peerAnnounceStorage = peerAnnounceStorage;
-    DHTRegistry::getMutableData().tokenTracker = tokenTracker;
-    DHTRegistry::getMutableData().messageDispatcher = dispatcher;
-    DHTRegistry::getMutableData().messageReceiver = receiver;
-    DHTRegistry::getMutableData().messageFactory = factory;
-
+    if(family == AF_INET) {
+      DHTRegistry::getMutableData().localNode = localNode;
+      DHTRegistry::getMutableData().routingTable = routingTable;
+      DHTRegistry::getMutableData().taskQueue = taskQueue;
+      DHTRegistry::getMutableData().taskFactory = taskFactory;
+      DHTRegistry::getMutableData().peerAnnounceStorage = peerAnnounceStorage;
+      DHTRegistry::getMutableData().tokenTracker = tokenTracker;
+      DHTRegistry::getMutableData().messageDispatcher = dispatcher;
+      DHTRegistry::getMutableData().messageReceiver = receiver;
+      DHTRegistry::getMutableData().messageFactory = factory;
+    } else {
+      DHTRegistry::getMutableData6().localNode = localNode;
+      DHTRegistry::getMutableData6().routingTable = routingTable;
+      DHTRegistry::getMutableData6().taskQueue = taskQueue;
+      DHTRegistry::getMutableData6().taskFactory = taskFactory;
+      DHTRegistry::getMutableData6().peerAnnounceStorage = peerAnnounceStorage;
+      DHTRegistry::getMutableData6().tokenTracker = tokenTracker;
+      DHTRegistry::getMutableData6().messageDispatcher = dispatcher;
+      DHTRegistry::getMutableData6().messageReceiver = receiver;
+      DHTRegistry::getMutableData6().messageFactory = factory;
+    }
     // add deserialized nodes to routing table
     const std::vector<SharedHandle<DHTNode> >& desnodes =
       deserializer.getNodes();
@@ -206,11 +219,16 @@ void DHTSetup::setup(std::vector<Command*>& commands, DownloadEngine* e)
       taskQueue->addPeriodicTask1(task);
     }
 
-    if(!e->getOption()->get(PREF_DHT_ENTRY_POINT_HOST).empty()) {
+    const std::string& prefEntryPointHost =
+      family == AF_INET?PREF_DHT_ENTRY_POINT_HOST:PREF_DHT_ENTRY_POINT_HOST6;
+    if(!e->getOption()->get(prefEntryPointHost).empty()) {
       {
+        const std::string& prefEntryPointPort =
+          family == AF_INET?PREF_DHT_ENTRY_POINT_PORT:
+          PREF_DHT_ENTRY_POINT_PORT6;
         std::pair<std::string, uint16_t> addr
-          (e->getOption()->get(PREF_DHT_ENTRY_POINT_HOST),
-           e->getOption()->getAsInt(PREF_DHT_ENTRY_POINT_PORT));
+          (e->getOption()->get(prefEntryPointHost),
+           e->getOption()->getAsInt(prefEntryPointPort));
         std::vector<std::pair<std::string, uint16_t> > entryPoints;
         entryPoints.push_back(addr);
         DHTEntryPointNameResolveCommand* command =
@@ -223,7 +241,7 @@ void DHTSetup::setup(std::vector<Command*>& commands, DownloadEngine* e)
         tempCommands->push_back(command);
       }
     } else {
-      logger_->info("No DHT entry point specified.");
+      A2_LOG_INFO("No DHT entry point specified.");
     }
     {
       DHTInteractionCommand* command =
@@ -258,24 +276,28 @@ void DHTSetup::setup(std::vector<Command*>& commands, DownloadEngine* e)
     }
     {
       DHTAutoSaveCommand* command =
-        new DHTAutoSaveCommand(e->newCUID(), e, 30*60);
+        new DHTAutoSaveCommand(e->newCUID(), e, family, 30*60);
       command->setLocalNode(localNode);
       command->setRoutingTable(routingTable);
       tempCommands->push_back(command);
     }
-    initialized_ = true;
+    if(family == AF_INET) {
+      DHTRegistry::setInitialized(true);
+    } else {
+      DHTRegistry::setInitialized6(true);
+    }
     commands.insert(commands.end(), tempCommands->begin(), tempCommands->end());
     tempCommands->clear();
   } catch(RecoverableException& e) {
-    logger_->error("Exception caught while initializing DHT functionality."
-                   " DHT is disabled.", e);
-    DHTRegistry::clearData();
+    A2_LOG_ERROR_EX(fmt("Exception caught while initializing DHT functionality."
+                        " DHT is disabled."),
+                    e);
+    if(family == AF_INET) {
+      DHTRegistry::clearData();
+    } else {
+      DHTRegistry::clearData6();
+    }
   }
 }
 
-bool DHTSetup::initialized()
-{
-  return initialized_;
-}
-
 } // namespace aria2
