@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_REQUEST_H_
-#define _D_HTTP_REQUEST_H_
+#ifndef D_HTTP_REQUEST_H
+#define D_HTTP_REQUEST_H
 
 #include "common.h"
 
@@ -42,11 +42,11 @@
 #include <vector>
 
 #include "SharedHandle.h"
-#include "Request.h"
 #include "FileEntry.h"
 
 namespace aria2 {
 
+class Request;
 class Segment;
 class Range;
 class Option;
@@ -59,102 +59,73 @@ private:
   
   static const std::string USER_AGENT;
 
-  SharedHandle<Request> request;
+  SharedHandle<Request> request_;
 
-  SharedHandle<FileEntry> _fileEntry;
+  SharedHandle<FileEntry> fileEntry_;
 
-  SharedHandle<Segment> segment;
+  SharedHandle<Segment> segment_;
 
-  bool _contentEncodingEnabled;
+  bool contentEncodingEnabled_;
 
-  std::string userAgent;
+  std::string userAgent_;
 
-  std::vector<std::string> _headers;
+  std::vector<std::string> headers_;
 
-  std::vector<std::string> _acceptTypes;
+  std::vector<std::string> acceptTypes_;
 
-  SharedHandle<CookieStorage> _cookieStorage;
+  SharedHandle<CookieStorage> cookieStorage_;
 
-  SharedHandle<AuthConfigFactory> _authConfigFactory;
+  SharedHandle<AuthConfigFactory> authConfigFactory_;
 
-  const Option* _option;
+  const Option* option_;
 
-  SharedHandle<AuthConfig> _authConfig;
+  SharedHandle<AuthConfig> authConfig_;
 
-  SharedHandle<Request> _proxyRequest;
+  SharedHandle<Request> proxyRequest_;
 
-  bool _noCache;
+  bool noCache_;
 
-  bool _acceptGzip;
+  bool acceptGzip_;
+
+  off_t endOffsetOverride_;
+
+  std::string ifModSinceHeader_;
 
   std::pair<std::string, std::string> getProxyAuthString() const;
 public:
   HttpRequest();
+  ~HttpRequest();
 
   const SharedHandle<Segment>& getSegment() const
   {
-    return segment;
+    return segment_;
   }
 
   void setSegment(const SharedHandle<Segment>& segment);
 
   void setRequest(const SharedHandle<Request>& request);
 
-  uint64_t getEntityLength() const
-  {
-    assert(!_fileEntry.isNull());
-    return _fileEntry->getLength();
-  }
+  uint64_t getEntityLength() const;
 
-  const std::string& getHost() const
-  {
-    return request->getHost();
-  }
+  const std::string& getHost() const;
 
-  uint16_t getPort() const
-  {
-    return request->getPort();
-  }
+  uint16_t getPort() const;
 
-  const std::string& getMethod() const
-  {
-    return request->getMethod();
-  }
+  const std::string& getMethod() const;
 
-  const std::string& getProtocol() const
-  {
-    return request->getProtocol();
-  }
+  const std::string& getProtocol() const;
 
-  const std::string& getCurrentURI() const
-  {
-    return request->getCurrentUri();
-  }
+  const std::string& getCurrentURI() const;
   
-  const std::string& getDir() const
-  {
-    return request->getDir();
-  }
+  const std::string& getDir() const;
 
-  const std::string& getFile() const
-  {
-    return request->getFile();
-  }
+  const std::string& getFile() const;
 
-  const std::string& getQuery() const
-  {
-    return request->getQuery();
-  }
+  const std::string& getQuery() const;
 
-  const std::string& getPreviousURI() const
-  {
-    return request->getPreviousUri();
-  }
+  const std::string& getPreviousURI() const;
 
-  std::string getURIHost() const
-  {
-    return request->getURIHost();
-  }
+  std::string getURIHost() const;
 
   SharedHandle<Range> getRange() const;
 
@@ -166,7 +137,7 @@ public:
 
   const SharedHandle<Request>& getRequest() const
   {
-    return request;
+    return request_;
   }
 
   off_t getStartByte() const;
@@ -176,8 +147,8 @@ public:
   /**
    * Returns string representation of http request.  It usually starts
    * with "GET ..." and ends with "\r\n".  The AuthConfig for this
-   * request is resolved using _authConfigFactory and stored in
-   * _authConfig.  getAuthConfig() returns AuthConfig used in the last
+   * request is resolved using authConfigFactory_ and stored in
+   * authConfig_.  getAuthConfig() returns AuthConfig used in the last
    * invocation of createRequest().
    */
   std::string createRequest();
@@ -192,10 +163,7 @@ public:
 
   void disableContentEncoding();
 
-  void setUserAgent(const std::string& userAgent)
-  {
-    this->userAgent = userAgent;
-  }
+  void setUserAgent(const std::string& userAgent);
   
   // accepts multiline headers, delimited by LF
   void addHeader(const std::string& headers);
@@ -205,14 +173,14 @@ public:
   template<typename InputIterator>
   void addAcceptType(InputIterator first, InputIterator last)
   {
-    _acceptTypes.insert(_acceptTypes.end(), first, last);
+    acceptTypes_.insert(acceptTypes_.end(), first, last);
   }
 
   void setCookieStorage(const SharedHandle<CookieStorage>& cookieStorage);
 
   const SharedHandle<CookieStorage>& getCookieStorage() const
   {
-    return _cookieStorage;
+    return cookieStorage_;
   }
 
   void setAuthConfigFactory
@@ -238,42 +206,51 @@ public:
   // createRequest().
   const SharedHandle<AuthConfig>& getAuthConfig() const;
 
-  void setFileEntry(const SharedHandle<FileEntry>& fileEntry)
-  {
-    _fileEntry = fileEntry;
-  }
+  void setFileEntry(const SharedHandle<FileEntry>& fileEntry);
 
   const SharedHandle<FileEntry>& getFileEntry() const
   {
-    return _fileEntry;
+    return fileEntry_;
   }
 
   void enableNoCache()
   {
-    _noCache = true;
+    noCache_ = true;
   }
 
   void disableNoCache()
   {
-    _noCache = false;
+    noCache_ = false;
   }
 
   void enableAcceptGZip()
   {
-    _acceptGzip = true;
+    acceptGzip_ = true;
   }
 
   void disableAcceptGZip()
   {
-    _acceptGzip = false;
+    acceptGzip_ = false;
   }
 
   bool acceptGZip() const
   {
-    return _acceptGzip;
+    return acceptGzip_;
+  }
+
+  void setEndOffsetOverride(off_t offset)
+  {
+    endOffsetOverride_ = offset;
+  }
+
+  void setIfModifiedSinceHeader(const std::string& hd);
+
+  const std::string& getIfModifiedSinceHeader() const
+  {
+    return ifModSinceHeader_;
   }
 };
 
 } // namespace aria2
 
-#endif // _D_HTTP_REQUEST_H_
+#endif // D_HTTP_REQUEST_H
