@@ -47,13 +47,14 @@
 #include "DHKeyExchange.h"
 #include "ARC4Encryptor.h"
 #include "ARC4Decryptor.h"
+#include "MessageDigest.h"
 #include "MessageDigestHelper.h"
 #include "SimpleRandomizer.h"
 #include "util.h"
 #include "DownloadContext.h"
 #include "prefs.h"
 #include "Option.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "bittorrent_helper.h"
 
 namespace aria2 {
@@ -64,22 +65,23 @@ const unsigned char* MSEHandshake::GENERATOR = reinterpret_cast<const unsigned c
 
 const unsigned char MSEHandshake::VC[] = { 0, 0, 0, 0, 0, 0, 0, 0 };
 
-MSEHandshake::MSEHandshake(cuid_t cuid,
-                           const SocketHandle& socket,
-                           const Option* op):
-  cuid_(cuid),
-  socket_(socket),
-  option_(op),
-  logger_(LogFactory::getInstance()),
-  rbufLength_(0),
-  socketBuffer_(socket),
-  negotiatedCryptoType_(CRYPTO_NONE),
-  dh_(0),
-  initiator_(true),
-  markerIndex_(0),
-  padLength_(0),
-  iaLength_(0),
-  ia_(0)
+MSEHandshake::MSEHandshake
+(cuid_t cuid,
+ const SocketHandle& socket,
+ const Option* op)
+  : cuid_(cuid),
+    socket_(socket),
+    option_(op),
+    rbufLength_(0),
+    socketBuffer_(socket),
+    negotiatedCryptoType_(CRYPTO_NONE),
+    dh_(0),
+    initiator_(true),
+    markerIndex_(0),
+    padLength_(0),
+    iaLength_(0),
+    ia_(0),
+    sha1_(MessageDigest::sha1())
 {}
 
 MSEHandshake::~MSEHandshake()
@@ -104,16 +106,12 @@ MSEHandshake::HANDSHAKE_TYPE MSEHandshake::identifyHandshakeType()
   }
   if(rbuf_[0] == BtHandshakeMessage::PSTR_LENGTH &&
      memcmp(BtHandshakeMessage::BT_PSTR, rbuf_+1, 19) == 0) {
-    if(logger_->debug()) {
-      logger_->debug("CUID#%s - This is legacy BitTorrent handshake.",
-                     util::itos(cuid_).c_str());
-    }
+    A2_LOG_DEBUG(fmt("CUID#%lld - This is legacy BitTorrent handshake.",
+                     cuid_));
     return HANDSHAKE_LEGACY;
   } else {
-    if(logger_->debug()) {
-      logger_->debug("CUID#%s - This may be encrypted BitTorrent handshake.",
-                     util::itos(cuid_).c_str());
-    }
+    A2_LOG_DEBUG(fmt("CUID#%lld - This may be encrypted BitTorrent handshake.",
+                     cuid_));
     return HANDSHAKE_ENCRYPTED;
   }
 }
@@ -124,19 +122,15 @@ void MSEHandshake::initEncryptionFacility(bool initiator)
   dh_ = new DHKeyExchange();
   dh_->init(PRIME, PRIME_BITS, GENERATOR, 160);
   dh_->generatePublicKey();
-  if(logger_->debug()) {
-    logger_->debug("CUID#%s - DH initialized.", util::itos(cuid_).c_str());
-  }
+  A2_LOG_DEBUG(fmt("CUID#%lld - DH initialized.", cuid_));
   initiator_ = initiator;
 }
 
 bool MSEHandshake::sendPublicKey()
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
-    if(logger_->debug()) {
-      logger_->debug("CUID#%s - Sending public key.",
-                     util::itos(cuid_).c_str());
-    }
+    A2_LOG_DEBUG(fmt("CUID#%lld - Sending public key.",
+                     cuid_));
     unsigned char buffer[KEY_LENGTH+MAX_PAD_LENGTH];
     dh_->getPublicKey(buffer, KEY_LENGTH);
 
@@ -155,9 +149,8 @@ bool MSEHandshake::receivePublicKey()
   if(r > receiveNBytes(r)) {
     return false;
   }
-  if(logger_->debug()) {
-    logger_->debug("CUID#%s - public key received.", util::itos(cuid_).c_str());
-  }
+  A2_LOG_DEBUG(fmt("CUID#%lld - public key received.",
+                   cuid_));
   // TODO handle exception. in catch, resbufLength = 0;
   dh_->computeSecret(secret_, sizeof(secret_), rbuf_, rbufLength_);
   // reset rbufLength_
@@ -175,17 +168,17 @@ void MSEHandshake::initCipher(const unsigned char* infoHash)
   memcpy(s+4+KEY_LENGTH, infoHash, INFO_HASH_LENGTH);
   
   unsigned char localCipherKey[20];
+  sha1_->reset();
   MessageDigestHelper::digest(localCipherKey, sizeof(localCipherKey),
-                              MessageDigestContext::SHA1,
-                              s, sizeof(s));
+                              sha1_, s, sizeof(s));
   encryptor_.reset(new ARC4Encryptor());
   encryptor_->init(localCipherKey, sizeof(localCipherKey));
 
   unsigned char peerCipherKey[20];
   memcpy(s, initiator_?"keyB":"keyA", 4);
+  sha1_->reset();
   MessageDigestHelper::digest(peerCipherKey, sizeof(peerCipherKey),
-                              MessageDigestContext::SHA1,
-                              s, sizeof(s));
+                              sha1_, s, sizeof(s));
   decryptor_.reset(new ARC4Decryptor());
   decryptor_->init(peerCipherKey, sizeof(peerCipherKey));
 
@@ -224,8 +217,8 @@ void MSEHandshake::createReq1Hash(unsigned char* md) const
   unsigned char buffer[100];
   memcpy(buffer, "req1", 4);
   memcpy(buffer+4, secret_, KEY_LENGTH);
-  MessageDigestHelper::digest(md, 20, MessageDigestContext::SHA1,
-                              buffer, 4+KEY_LENGTH);
+  sha1_->reset();
+  MessageDigestHelper::digest(md, 20, sha1_, buffer, 4+KEY_LENGTH);
 }
 
 void MSEHandshake::createReq23Hash(unsigned char* md, const unsigned char* infoHash) const
@@ -234,15 +227,15 @@ void MSEHandshake::createReq23Hash(unsigned char* md, const unsigned char* infoH
   memcpy(x, "req2", 4);
   memcpy(x+4, infoHash, INFO_HASH_LENGTH);
   unsigned char xh[20];
-  MessageDigestHelper::digest(xh, sizeof(xh), MessageDigestContext::SHA1,
-                              x, sizeof(x));
+  sha1_->reset();
+  MessageDigestHelper::digest(xh, sizeof(xh), sha1_, x, sizeof(x));
 
   unsigned char y[4+96];
   memcpy(y, "req3", 4);
   memcpy(y+4, secret_, KEY_LENGTH);
   unsigned char yh[20];
-  MessageDigestHelper::digest(yh, sizeof(yh), MessageDigestContext::SHA1,
-                              y, sizeof(y));
+  sha1_->reset();
+  MessageDigestHelper::digest(yh, sizeof(yh), sha1_, y, sizeof(y));
   
   for(size_t i = 0; i < 20; ++i) {
     md[i] = xh[i]^yh[i];
@@ -261,10 +254,8 @@ uint16_t MSEHandshake::decodeLength16(const unsigned char* buffer)
 bool MSEHandshake::sendInitiatorStep2()
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
-    if(logger_->debug()) {
-      logger_->debug("CUID#%s - Sending negotiation step2.",
-                     util::itos(cuid_).c_str());
-    }
+    A2_LOG_DEBUG(fmt("CUID#%lld - Sending negotiation step2.",
+                     cuid_));
     unsigned char md[20];
     createReq1Hash(md);
     socketBuffer_.pushStr(std::string(&md[0], &md[sizeof(md)]));
@@ -350,11 +341,9 @@ bool MSEHandshake::findInitiatorVCMarker()
   size_t toRead = markerIndex_+VC_LENGTH-rbufLength_;
   socket_->readData(rbuf_+rbufLength_, toRead);
   rbufLength_ += toRead;
-  if(logger_->debug()) {
-    logger_->debug("CUID#%s - VC marker found at %lu",
-                   util::itos(cuid_).c_str(),
-                   static_cast<unsigned long>(markerIndex_));
-  }
+  A2_LOG_DEBUG(fmt("CUID#%lld - VC marker found at %lu",
+                   cuid_,
+                   static_cast<unsigned long>(markerIndex_)));
   verifyVC(rbuf_+markerIndex_);
   // reset rbufLength_
   rbufLength_ = 0;
@@ -375,23 +364,19 @@ bool MSEHandshake::receiveInitiatorCryptoSelectAndPadDLength()
                         rbufptr, sizeof(cryptoSelect));
     if(cryptoSelect[3]&CRYPTO_PLAIN_TEXT &&
        option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
-      if(logger_->debug()) {
-        logger_->debug("CUID#%s - peer prefers plaintext.",
-                       util::itos(cuid_).c_str());
-      }
+      A2_LOG_DEBUG(fmt("CUID#%lld - peer prefers plaintext.",
+                       cuid_));
       negotiatedCryptoType_ = CRYPTO_PLAIN_TEXT;
     }
     if(cryptoSelect[3]&CRYPTO_ARC4) {
-      if(logger_->debug()) {
-        logger_->debug("CUID#%s - peer prefers ARC4",
-                       util::itos(cuid_).c_str());
-      }
+      A2_LOG_DEBUG(fmt("CUID#%lld - peer prefers ARC4",
+                       cuid_));
       negotiatedCryptoType_ = CRYPTO_ARC4;
     }
     if(negotiatedCryptoType_ == CRYPTO_NONE) {
       throw DL_ABORT_EX
-        (StringFormat("CUID#%s - No supported crypto type selected.",
-                      util::itos(cuid_).c_str()).str());
+        (fmt("CUID#%lld - No supported crypto type selected.",
+             cuid_));
     }
   }
   // padD length
@@ -452,11 +437,9 @@ bool MSEHandshake::findReceiverHashMarker()
   size_t toRead = markerIndex_+20-rbufLength_;
   socket_->readData(rbuf_+rbufLength_, toRead);
   rbufLength_ += toRead;
-  if(logger_->debug()) {
-    logger_->debug("CUID#%s - Hash marker found at %lu.",
-                   util::itos(cuid_).c_str(),
-                   static_cast<unsigned long>(markerIndex_));
-  }
+  A2_LOG_DEBUG(fmt("CUID#%lld - Hash marker found at %lu.",
+                   cuid_,
+                   static_cast<unsigned long>(markerIndex_)));
   verifyReq1Hash(rbuf_+markerIndex_);
   // reset rbufLength_
   rbufLength_ = 0;
@@ -481,16 +464,14 @@ bool MSEHandshake::receiveReceiverHashAndPadCLength
     const unsigned char* infohash = bittorrent::getInfoHash(*i);
     createReq23Hash(md, infohash);
     if(memcmp(md, rbufptr, sizeof(md)) == 0) {
-      if(logger_->debug()) {
-        logger_->debug("CUID#%s - info hash found: %s",
-                       util::itos(cuid_).c_str(),
-                       util::toHex(infohash, INFO_HASH_LENGTH).c_str());
-      }
+      A2_LOG_DEBUG(fmt("CUID#%lld - info hash found: %s",
+                       cuid_,
+                       util::toHex(infohash, INFO_HASH_LENGTH).c_str()));
       downloadContext = *i;
       break;
     }
   }
-  if(downloadContext.isNull()) {
+  if(!downloadContext) {
     throw DL_ABORT_EX("Unknown info hash.");
   }
   initCipher(bittorrent::getInfoHash(downloadContext));
@@ -507,22 +488,18 @@ bool MSEHandshake::receiveReceiverHashAndPadCLength
     // For now, choose ARC4.
     if(cryptoProvide[3]&CRYPTO_PLAIN_TEXT &&
        option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
-      if(logger_->debug()) {
-        logger_->debug("CUID#%s - peer provides plaintext.",
-                       util::itos(cuid_).c_str());
-      }
+      A2_LOG_DEBUG(fmt("CUID#%lld - peer provides plaintext.",
+                       cuid_));
       negotiatedCryptoType_ = CRYPTO_PLAIN_TEXT;
     } else if(cryptoProvide[3]&CRYPTO_ARC4) {
-      if(logger_->debug()) {
-        logger_->debug("CUID#%s - peer provides ARC4.",
-                       util::itos(cuid_).c_str());
-      }
+      A2_LOG_DEBUG(fmt("CUID#%lld - peer provides ARC4.",
+                       cuid_));
       negotiatedCryptoType_ = CRYPTO_ARC4;
     }
     if(negotiatedCryptoType_ == CRYPTO_NONE) {
       throw DL_ABORT_EX
-        (StringFormat("CUID#%s - No supported crypto type provided.",
-                      util::itos(cuid_).c_str()).str());
+        (fmt("CUID#%lld - No supported crypto type provided.",
+             cuid_));
     }
   }
   // decrypt PadC length
@@ -541,10 +518,8 @@ bool MSEHandshake::receiveReceiverIALength()
     return false;
   }
   iaLength_ = decodeLength16(rbuf_);
-  if(logger_->debug()) {
-    logger_->debug("CUID#%s - len(IA)=%u.",
-                   util::itos(cuid_).c_str(), iaLength_);
-  }
+  A2_LOG_DEBUG(fmt("CUID#%lld - len(IA)=%u.",
+                   cuid_, iaLength_));
   // reset rbufLength_
   rbufLength_ = 0;
   return true;
@@ -562,9 +537,7 @@ bool MSEHandshake::receiveReceiverIA()
   delete [] ia_;
   ia_ = new unsigned char[iaLength_];
   decryptor_->decrypt(ia_, iaLength_, rbuf_, iaLength_);
-  if(logger_->debug()) {
-    logger_->debug("CUID#%s - IA received.", util::itos(cuid_).c_str());
-  }
+  A2_LOG_DEBUG(fmt("CUID#%lld - IA received.", cuid_));
   // reset rbufLength_
   rbufLength_ = 0;
   return true;
@@ -603,40 +576,32 @@ bool MSEHandshake::sendReceiverStep2()
 
 uint16_t MSEHandshake::verifyPadLength(const unsigned char* padlenbuf, const char* padName)
 {
-  if(logger_->debug()) {
-    logger_->debug("CUID#%s - Verifying Pad length for %s",
-                   util::itos(cuid_).c_str(), padName);
-  }
+  A2_LOG_DEBUG(fmt("CUID#%lld - Verifying Pad length for %s",
+                   cuid_, padName));
   uint16_t padLength = decodeLength16(padlenbuf);
-  if(logger_->debug()) {
-    logger_->debug("CUID#%s - len(%s)=%u",
-                   util::itos(cuid_).c_str(), padName, padLength);
-  }
+  A2_LOG_DEBUG(fmt("CUID#%lld - len(%s)=%u",
+                   cuid_, padName, padLength));
   if(padLength > 512) {
     throw DL_ABORT_EX
-      (StringFormat("Too large %s length: %u", padName, padLength).str());
+      (fmt("Too large %s length: %u", padName, padLength));
   }
   return padLength;
 }
 
 void MSEHandshake::verifyVC(const unsigned char* vcbuf)
 {
-  if(logger_->debug()) {
-    logger_->debug("CUID#%s - Verifying VC.", util::itos(cuid_).c_str());
-  }
+  A2_LOG_DEBUG(fmt("CUID#%lld - Verifying VC.", cuid_));
   unsigned char vc[VC_LENGTH];
   decryptor_->decrypt(vc, sizeof(vc), vcbuf, sizeof(vc));
   if(memcmp(VC, vc, sizeof(VC)) != 0) {
     throw DL_ABORT_EX
-      (StringFormat("Invalid VC: %s", util::toHex(vc, VC_LENGTH).c_str()).str());
+      (fmt("Invalid VC: %s", util::toHex(vc, VC_LENGTH).c_str()));
   }
 }
 
 void MSEHandshake::verifyReq1Hash(const unsigned char* req1buf)
 {
-  if(logger_->debug()) {
-    logger_->debug("CUID#%s - Verifying req hash.", util::itos(cuid_).c_str());
-  }
+  A2_LOG_DEBUG(fmt("CUID#%lld - Verifying req hash.", cuid_));
   unsigned char md[20];
   createReq1Hash(md);
   if(memcmp(md, req1buf, sizeof(md)) != 0) {
