@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_XML_RPC_METHOD_H_
-#define _D_XML_RPC_METHOD_H_
+#ifndef D_XML_RPC_METHOD_H
+#define D_XML_RPC_METHOD_H
 
 #include "common.h"
 
@@ -46,7 +46,6 @@ namespace aria2 {
 
 class DownloadEngine;
 class OptionParser;
-class Logger;
 class Option;
 class Exception;
 
@@ -65,8 +64,6 @@ struct XmlRpcResponse;
 class XmlRpcMethod {
 private:
   SharedHandle<OptionParser> optionParser_;
-
-  Logger* logger_;
 protected:
   // Subclass must implement this function to fulfil XmlRpcRequest
   // req.  The return value of this method is used as a return value
@@ -100,7 +97,7 @@ protected:
 public:
   XmlRpcMethod();
 
-  virtual ~XmlRpcMethod() {}
+  virtual ~XmlRpcMethod();
 
   // Do work to fulfill XmlRpcRequest req and returns its result as
   // XmlRpcResponse. This method delegates to process() method.
@@ -111,4 +108,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_XML_RPC_METHOD_H_
+#endif // D_XML_RPC_METHOD_H
