@@ -6,7 +6,6 @@
 #include "SelectEventPoll.h"
 #include "Option.h"
 #include "RequestGroupMan.h"
-#include "ServerStatMan.h"
 #include "RequestGroup.h"
 #include "XmlRpcMethodImpl.h"
 #include "OptionParser.h"
@@ -20,15 +19,10 @@
 #include "util.h"
 #include "array_fun.h"
 #include "download_helper.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
+#include "FileEntry.h"
 #ifdef ENABLE_BITTORRENT
 # include "BtRegistry.h"
 # include "BtRuntime.h"
-# include "PieceStorage.h"
-# include "PeerStorage.h"
-# include "BtProgressInfoFile.h"
-# include "BtAnnounce.h"
 # include "bittorrent_helper.h"
 #endif // ENABLE_BITTORRENT
 
@@ -150,10 +144,12 @@ public:
 
 CPPUNIT_TEST_SUITE_REGISTRATION(XmlRpcMethodTest);
 
-static std::string getString(const Dict* dict, const std::string& key)
+namespace {
+std::string getString(const Dict* dict, const std::string& key)
 {
   return asString(dict->get(key))->s();
 }
+} // namespace
 
 void XmlRpcMethodTest::testAddUri()
 {
@@ -181,7 +177,7 @@ void XmlRpcMethodTest::testAddUri()
     CPPUNIT_ASSERT_EQUAL(0, res.code);
     CPPUNIT_ASSERT_EQUAL(std::string("/sink"),
                          e_->getRequestGroupMan()->findReservedGroup(2)->
-                         getDownloadContext()->getDir());
+                         getOption()->get(PREF_DIR));
   }
 }
 
@@ -261,7 +257,7 @@ void XmlRpcMethodTest::testAddTorrent()
 {
   AddTorrentXmlRpcMethod m;
   XmlRpcRequest req(AddTorrentXmlRpcMethod::getMethodName(), List::g());
-  req.params->append(readFile("single.torrent"));
+  req.params->append(readFile(A2_TEST_DIR"/single.torrent"));
   SharedHandle<List> uris = List::g();
   uris->append("http://localhost/aria2-0.8.2.tar.bz2");
   req.params->append(uris);
@@ -272,7 +268,7 @@ void XmlRpcMethodTest::testAddTorrent()
 
     SharedHandle<RequestGroup> group =
       e_->getRequestGroupMan()->findReservedGroup(1);
-    CPPUNIT_ASSERT(!group.isNull());
+    CPPUNIT_ASSERT(group);
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/aria2-0.8.2.tar.bz2"),
                          group->getFirstFilePath());
     CPPUNIT_ASSERT_EQUAL((size_t)1,
@@ -316,14 +312,14 @@ void XmlRpcMethodTest::testAddTorrent_withPosition()
 {
   AddTorrentXmlRpcMethod m;
   XmlRpcRequest req1(AddTorrentXmlRpcMethod::getMethodName(), List::g());
-  req1.params->append(readFile("test.torrent"));
+  req1.params->append(readFile(A2_TEST_DIR"/test.torrent"));
   req1.params->append(List::g());
   req1.params->append(Dict::g());
   XmlRpcResponse res1 = m.execute(req1, e_.get());
   CPPUNIT_ASSERT_EQUAL(0, res1.code);
 
   XmlRpcRequest req2(AddTorrentXmlRpcMethod::getMethodName(), List::g());
-  req2.params->append(readFile("single.torrent"));
+  req2.params->append(readFile(A2_TEST_DIR"/single.torrent"));
   req2.params->append(List::g());
   req2.params->append(Dict::g());
   req2.params->append(Integer::g(0));
@@ -341,7 +337,7 @@ void XmlRpcMethodTest::testAddMetalink()
 {
   AddMetalinkXmlRpcMethod m;
   XmlRpcRequest req(AddMetalinkXmlRpcMethod::getMethodName(), List::g());
-  req.params->append(readFile("2files.metalink"));
+  req.params->append(readFile(A2_TEST_DIR"/2files.metalink"));
   {
     XmlRpcResponse res = m.execute(req, e_.get());
     CPPUNIT_ASSERT_EQUAL(0, res.code);
@@ -352,12 +348,12 @@ void XmlRpcMethodTest::testAddMetalink()
 
     SharedHandle<RequestGroup> tar =
       e_->getRequestGroupMan()->findReservedGroup(1);
-    CPPUNIT_ASSERT(!tar.isNull());
+    CPPUNIT_ASSERT(tar);
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/aria2-5.0.0.tar.bz2"),
                          tar->getFirstFilePath());
     SharedHandle<RequestGroup> deb =
       e_->getRequestGroupMan()->findReservedGroup(2);
-    CPPUNIT_ASSERT(!deb.isNull());
+    CPPUNIT_ASSERT(deb);
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/aria2-5.0.0.deb"),
                          deb->getFirstFilePath());
   }
@@ -403,7 +399,7 @@ void XmlRpcMethodTest::testAddMetalink_withPosition()
 
   AddMetalinkXmlRpcMethod m2;
   XmlRpcRequest req2("ari2.addMetalink", List::g());
-  req2.params->append(readFile("2files.metalink"));
+  req2.params->append(readFile(A2_TEST_DIR"/2files.metalink"));
   req2.params->append(Dict::g());
   req2.params->append(Integer::g(0));
   XmlRpcResponse res2 = m2.execute(req2, e_.get());
@@ -587,8 +583,8 @@ void XmlRpcMethodTest::testTellStatus_withoutGid()
   CPPUNIT_ASSERT_EQUAL(1, res.code);
 }
 
-static void addUri(const std::string& uri,
-                   const SharedHandle<DownloadEngine>& e)
+namespace {
+void addUri(const std::string& uri, const SharedHandle<DownloadEngine>& e)
 {
   AddUriXmlRpcMethod m;
   XmlRpcRequest req(AddUriXmlRpcMethod::getMethodName(), List::g());
@@ -597,10 +593,11 @@ static void addUri(const std::string& uri,
   req.params->append(urisParam);
   CPPUNIT_ASSERT_EQUAL(0, m.execute(req, e.get()).code);
 }
+} // namespace
 
 #ifdef ENABLE_BITTORRENT
-
-static void addTorrent
+namespace {
+void addTorrent
 (const std::string& torrentFile, const SharedHandle<DownloadEngine>& e)
 {
   AddTorrentXmlRpcMethod m;
@@ -608,7 +605,7 @@ static void addTorrent
   req.params->append(readFile(torrentFile));
   XmlRpcResponse res = m.execute(req, e.get());
 }
-
+} // namespace
 #endif // ENABLE_BITTORRENT
 
 void XmlRpcMethodTest::testTellWaiting()
@@ -617,7 +614,7 @@ void XmlRpcMethodTest::testTellWaiting()
   addUri("http://2/", e_);
   addUri("http://3/", e_);
 #ifdef ENABLE_BITTORRENT
-  addTorrent("single.torrent", e_);
+  addTorrent(A2_TEST_DIR"/single.torrent", e_);
 #else // !ENABLE_BITTORRENT
   addUri("http://4/", e_);
 #endif // !ENABLE_BITTORRENT
@@ -724,17 +721,25 @@ void XmlRpcMethodTest::testGatherStoppedDownload()
   d->inMemoryDownload = false;
   d->sessionDownloadLength = UINT64_MAX;
   d->sessionTime = 1000;
-  d->result = downloadresultcode::FINISHED;
+  d->result = error_code::FINISHED;
   d->followedBy = followedBy;
   d->belongsTo = 2;
   SharedHandle<Dict> entry = Dict::g();
-  gatherStoppedDownload(entry, d);
+  std::vector<std::string> keys;
+  gatherStoppedDownload(entry, d, keys);
 
   const List* followedByRes = asList(entry->get("followedBy"));
   CPPUNIT_ASSERT_EQUAL(std::string("3"), asString(followedByRes->get(0))->s());
   CPPUNIT_ASSERT_EQUAL(std::string("4"), asString(followedByRes->get(1))->s());
   CPPUNIT_ASSERT_EQUAL(std::string("2"),
                        asString(entry->get("belongsTo"))->s());
+
+  keys.push_back("gid");
+
+  entry = Dict::g();
+  gatherStoppedDownload(entry, d, keys);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, entry->size());
+  CPPUNIT_ASSERT(entry->containsKey("gid"));
 }
 
 void XmlRpcMethodTest::testGatherProgressCommon()
@@ -742,7 +747,6 @@ void XmlRpcMethodTest::testGatherProgressCommon()
   SharedHandle<DownloadContext> dctx(new DownloadContext(0, 0,"aria2.tar.bz2"));
   std::string uris[] = { "http://localhost/aria2.tar.bz2" };
   dctx->getFirstFileEntry()->addUris(vbegin(uris), vend(uris));
-  dctx->setDir(option_->get(PREF_DIR));
   SharedHandle<RequestGroup> group(new RequestGroup(option_));
   group->setDownloadContext(dctx);
   std::vector<SharedHandle<RequestGroup> > followedBy;
@@ -754,7 +758,8 @@ void XmlRpcMethodTest::testGatherProgressCommon()
   group->belongsTo(2);
 
   SharedHandle<Dict> entry = Dict::g();
-  gatherProgressCommon(entry, group);
+  std::vector<std::string> keys;
+  gatherProgressCommon(entry, group, keys);
   
   const List* followedByRes = asList(entry->get("followedBy"));
   CPPUNIT_ASSERT_EQUAL(util::itos(followedBy[0]->getGID()),
@@ -775,13 +780,23 @@ void XmlRpcMethodTest::testGatherProgressCommon()
                         ->get("uri"))
                        ->s());
   CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), asString(entry->get("dir"))->s());
+
+  keys.push_back("gid");
+  entry = Dict::g();
+  gatherProgressCommon(entry, group, keys);
+
+  CPPUNIT_ASSERT_EQUAL((size_t)1, entry->size());
+  CPPUNIT_ASSERT(entry->containsKey("gid"));
+  
 }
 
 #ifdef ENABLE_BITTORRENT
 void XmlRpcMethodTest::testGatherBitTorrentMetadata()
 {
+  SharedHandle<Option> option(new Option());
+  option->put(PREF_DIR, ".");
   SharedHandle<DownloadContext> dctx(new DownloadContext());
-  bittorrent::load("test.torrent", dctx);
+  bittorrent::load(A2_TEST_DIR"/test.torrent", dctx, option);
   SharedHandle<Dict> btDict = Dict::g();
   gatherBitTorrentMetadata(btDict, bittorrent::getTorrentAttrs(dctx));
   CPPUNIT_ASSERT_EQUAL(std::string("REDNOAH.COM RULES"),
